package
Version:
v0.6.0
Opens a new window with list of versions in this module.
Published: May 7, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
NewCmdVariable returns the top-level "variable" command with subcommands.
type Variable struct {
UUID string `json:"uuid"`
Key string `json:"key"`
Value string `json:"value"`
Secured bool `json:"secured"`
}
Variable represents a Bitbucket pipeline variable.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.